==> haskell-x509-1.7.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.1
id: x509-1.7.1-5Bdd4fklHRL9Z7KJVZ3ngA
key: x509-1.7.1-5Bdd4fklHRL9Z7KJVZ3ngA
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: 82918713c8ca873e735300339db82529
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-1.7.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-1.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/x509-1.7.1
hs-libraries: HSx509-1.7.1-5Bdd4fklHRL9Z7KJVZ3ngA
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-parse-0.9.4-FsGQ4474sNEAmfHowfpG3
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.2
id: x509-1.7.2-8XP1uUZYB4C7XBwX9PCMZ2
key: x509-1.7.2-8XP1uUZYB4C7XBwX9PCMZ2
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: d5b5998535e4ca49bc4ab524c51d7d41
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-1.7.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/x509-1.7.2
hs-libraries: HSx509-1.7.2-8XP1uUZYB4C7XBwX9PCMZ2
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-parse-0.9.4-FsGQ4474sNEAmfHowfpG3
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
